#!/bin/bash

want_cic_cache_version=0.2.1a9
want_cicada_version=0.0.1a6
want_evm=bloxberg

. aux/bdbg/bdbg.sh
_level=2
_debug=1

PIP_EXTRA_ARGS=$PIP_EXTRA_ARGS
PIP_EXTRA_INDEX_URL=${PIP_EXTRA_INDEX_URL:-https://pip.grassrootseconomics.net:8433}
PIP_INDEX_URL=${PIP_INDEX_URL:-"https://pypi.org/simple"}
CIC_SETUP_TRUSTED_FINGERPRINT=${CIC_SETUP_TRUSTED_FINGERPRINT:-0826EDA1702D1E87C6E2875121D2E7BB88C2A746}

if [ "$UID" -eq 0 ]; then
	dbg $dbg_error "This cannot be run as root"
	exit 1
fi


dbg $dbg_debug "checking installed versions"

update=0
v=`pip show cic-cache | awk '/^Version/ {print $2;}'`
if [ "$?" -ne 0 ]; then
	dbg $dbg_warn "cic-cache is not installed. will update"
	update=1
elif [ "$v" != "$want_cic_cache_version" ]; then
	dbg $dbg_warn "cli-cache version $v installed but need $want_cic_cache_version, will update"
	update=1
else
	dbg $dbg_info "cli-cache version $v ok"
fi

v=`pip show clicada | awk '/^Version/ {print $2;}'`
if [ "$?" -ne 0 ]; then
	dbg $dbg_warn "clicada is not installed, will update"
	update=1
elif [ "$v" != "$want_cicada_version" ]; then
	dbg $dbg_warn "clicada version $v installed but need $want_cicada_version, will update"
	update=1
else
	dbg $dbg_info "clicada version $v ok"
fi

set -e

if [ $update -gt 0 ]; then
	dbg $dbg_debug "installing application files"

	debug_flag=
	if [ "$_level" -eq 1 ]; then
		debug_flag="-v"
	fi
	pip install --index-url $PIP_INDEX_URL --extra-index-url $PIP_EXTRA_INDEX_URL $PIP_EXTRA_ARGS $debug_flag -r requirements.txt
fi

dbg $dbg_debug "importing keys"
for f in ./keys/*.asc; do
	gpg --import $f
done

dbg $dbg_debug "installing configurations"

t=`mktemp`
if [ -f $HOME/.config/cic/cache/config.ini ]; then
	dbg $dbg_debug "migrating existing configuration"
	config_flag="-c $HOME/.config/cic/cache"
fi
cic-cache-trackerd --dumpconfig ini $config_flag -vv > $t
mkdir -vp $HOME/.config/cic/cache
mv -v $t $HOME/.config/cic/cache/confini.ini

if [ -d $HOME/.config/cic/clicada/config.ini ]; then
	dbg $dbg_debug "migrating existing clicada configuration"
	config_flag="-c $HOME/.config/cic/clicada"
fi
clicada --dumpconfig ini $config_flag -vv > $t
mkdir -vp $HOME/.config/cic/clicada
mv -v $t $HOME/.config/cic/clicada/confini.ini

if [ ! -z $want_evm ]; then
	. setup_${want_evm}.sh
fi	
set +e
